Type: Package
Package: MigConnectivity
Title: Estimate Migratory Connectivity for Migratory Animals
Version: 0.5.0
Date: 2025-08-01
Authors@R: c(
    person("Jeffrey A.", "Hostetler", , "jhostetler@usgs.gov", role = c("cre", "aut")),
    person("Michael T.", "Hallworth", role = "aut"),
    person("Clark S.", "Rushing", role = "ctb"),
    person("Emily B.", "Cohen", role = "ctb"),
    person("Valentine", "Herrmann", role = "ctb"),
    person("Henry", "Stevens", role = "ctb")
  )
Description: Allows the user to estimate transition probabilities for
    migratory animals between any two phases of the annual cycle, using a
    variety of different data types. Also quantifies the strength of
    migratory connectivity (MC), a standardized metric to quantify the
    extent to which populations co-occur between two phases of the annual
    cycle. Includes functions to estimate MC and the more traditional
    metric of migratory connectivity strength (Mantel correlation)
    incorporating uncertainty from multiple sources of sampling error. For
    cross-species comparisons, methods are provided to estimate
    differences in migratory connectivity strength, incorporating
    uncertainty. See Cohen et al. (2018) <doi:10.1111/2041-210X.12916>,
    Cohen et al. (2019) <doi:10.1111/ecog.03974>, Roberts et al. (2023)
    <doi:10.1002/eap.2788>, and Hostetler et al. (2025)
    <doi:10.1111/2041-210X.14467> for details on some of these methods.
License: GPL (>= 3)
URL: https://github.com/SMBC-NZP/MigConnectivity
Depends: R (>= 3.5.0)
Imports: coda, geodist, gplots, graphics, grDevices, MASS, methods,
        ncf, R2jags, RMark (>= 2.1.14), sf, shape, stats, terra, utils,
        VGAM
Suggests: knitr, maps, rmarkdown, testthat
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
RoxygenNote: 7.3.2
SystemRequirements: JAGS (https://mcmc-jags.sourceforge.net)
NeedsCompilation: no
Packaged: 2025-08-26 15:10:58 UTC; jhostetler
Author: Jeffrey A. Hostetler [cre, aut],
  Michael T. Hallworth [aut],
  Clark S. Rushing [ctb],
  Emily B. Cohen [ctb],
  Valentine Herrmann [ctb],
  Henry Stevens [ctb]
Maintainer: Jeffrey A. Hostetler <jhostetler@usgs.gov>
Repository: CRAN
Date/Publication: 2025-08-27 08:00:13 UTC
Built: R 4.6.0; ; 2025-08-27 08:40:25 UTC; unix
