# Generated by roxygen2: do not edit by hand

S3method(plot,estMigConnectivity)
S3method(plot,intrinsicAssign)
S3method(print,estMigConnectivity)
S3method(print,intrinsicAssign)
S3method(summary,estMigConnectivity)
S3method(summary,intrinsicAssign)
export(calcMC)
export(calcMantel)
export(calcNMC)
export(calcPsi)
export(calcStrength)
export(calcTransition)
export(diffCorr)
export(diffMC)
export(diffMantel)
export(diffStrength)
export(distFromPos)
export(estCorr)
export(estMC)
export(estMantel)
export(estNMC)
export(estPsi)
export(estStrength)
export(estTransition)
export(getCMRexample)
export(getIsoMap)
export(isoAssign)
export(modelCountDataJAGS)
export(reversePi)
export(reversePsiRelAbund)
export(reverseTransition)
export(reverseTransitionRelAbund)
export(simCMRData)
export(simCountData)
export(simGLData)
export(simMove)
export(simProbData)
export(simTelemetryData)
export(weightAssign)
import(stats)
